@@ -15,7 +15,7 @@ use LWP::Protocol ();
 use Scalar::Util qw(blessed);
 use Try::Tiny qw(try catch);
 
-our $VERSION = '6.44';
+our $VERSION = '6.45';
 
 sub new
 {
@@ -300,7 +300,7 @@ sub request {
     my $response = $self->simple_request($request, $arg, $size);
     $response->previous($previous) if $previous;
 
-    if ($response->redirects >= $self->{max_redirect}) {
+    if ($response->header('Location') && $response->redirects >= $self->{max_redirect}) {
         $response->header("Client-Warning" =>
                 "Redirect loop detected (max_redirect = $self->{max_redirect})"
         );
